pub enum ReaderError {
IoError(Error),
FromUtf8Error(FromUtf8Error),
InvalidColorId(u8),
InvalidOrientation(u8),
InvalidMagicNumber([u8; 3]),
UnsupportedVersion(u8),
InvalidBlockType(u8),
InvalidBrickTypeId(u16),
}Expand description
An error which may be returned when reading from a Reader.
Variants
IoError(Error)
An IO error has occured in the underlying Read.
FromUtf8Error(FromUtf8Error)
A string was encountered that isn’t valid utf-8.
InvalidColorId(u8)
A color id has been encountered that isn’t in the palette.
InvalidOrientation(u8)
An orientation that is outside of the 0..=3 range has been encountered.
InvalidMagicNumber([u8; 3])
This Read doesn’t start with b"ttb".
UnsupportedVersion(u8)
This version is not supported by this crate.
InvalidBlockType(u8)
An invalid block type has been encountered.
InvalidBrickTypeId(u16)
A brick has been encountered that has a brick type that isn’t in the brick type table.